
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "source/auto_examples/ceil_example.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_source_auto_examples_ceil_example.py>`
        to download the full example code

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_source_auto_examples_ceil_example.py:


======================================
Example for looking at ceilometer data
======================================

This is an example of how to download and
plot ceiliometer data from the SGP site
over Oklahoma.

.. image:: ../../plot_ceil_example.png

.. GENERATED FROM PYTHON SOURCE LINES 12-30

.. code-block:: default


    import act
    import matplotlib.pyplot as plt

    # Place your username and token here
    username = ''
    token = ''

    act.discovery.download_data(username, token, 'sgpceilC1.b1',
                                '2017-01-14', '2017-01-19')

    ceil_ds = act.io.armfiles.read_netcdf('sgpceilC1.b1/*')
    print(ceil_ds)
    ceil_ds = act.corrections.ceil.correct_ceil(ceil_ds, -9999.)
    display = act.plotting.TimeSeriesDisplay(
        ceil_ds, subplot_shape=(1, ), figsize=(15, 5))
    display.plot('backscatter', subplot_index=(0, ))
    plt.show()


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  0.000 seconds)


.. _sphx_glr_download_source_auto_examples_ceil_example.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: ceil_example.py <ceil_example.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: ceil_example.ipynb <ceil_example.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
